@@ -1,6 +1,6 @@
 """ This module contains a func
 and only one """
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """ recursive for loop """
     for each_item in the_list:
         if isinstance(each_item, list):
